Python API
==========

.. automodule:: wmflib

.. autodata:: __version__

.. rubric:: Subpackages and Submodules

.. toctree::

    wmflib.actions
    wmflib.config
    wmflib.constants
    wmflib.decorators
    wmflib.dns
    wmflib.exceptions
    wmflib.fileio
    wmflib.idm
    wmflib.interactive
    wmflib.irc
    wmflib.phabricator
    wmflib.prometheus
    wmflib.requests
